@@ -1,7 +1,7 @@
 package Config::IOD;
 
 our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -175,7 +175,7 @@ Config::IOD - Read and write IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.11 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-18.
+This document describes version 0.12 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-18.
 
 =head1 SYNOPSIS
 
@@ -304,6 +304,30 @@ instead of the correct:
 is very common, the spec allows it. This reader, however, can be configured to
 be more strict.
 
+=head2 allow_duplicate_key => bool (default: 1)
+
+If set to 0, you can forbid duplicate key, e.g.:
+
+ [section]
+ a=1
+ a=2
+
+or:
+
+ [section]
+ a=1
+ b=2
+ c=3
+ a=10
+
+In traditional INI file, to specify an array you specify multiple keys. But when
+there is only a single key, it is unclear if the value is a single-element array
+or a scalar. You can use this setting to avoid this array/scalar ambiguity in
+config file and force user to use JSON encoding or bracket to specify array:
+
+ [section]
+ a=[1,2]
+
 =head1 METHODS
 
 =head2 new(%attrs) => obj
